==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/webpubsub/kotlin/inputs/WebPubSubTlsSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.webpubsub.kotlin.inputs

import com.pulumi.azurenative.webpubsub.inputs.WebPubSubTlsSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * TLS settings for the resource
 * @property clientCertEnabled Request client certificate during TLS handshake if enabled
 */
public data class WebPubSubTlsSettingsArgs(
    public val clientCertEnabled: Output<Boolean>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.webpubsub.inputs.WebPubSubTlsSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.webpubsub.inputs.WebPubSubTlsSettingsArgs =
        com.pulumi.azurenative.webpubsub.inputs.WebPubSubTlsSettingsArgs.builder()
            .clientCertEnabled(clientCertEnabled?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WebPubSubTlsSettingsArgs].
 */
@PulumiTagMarker
public class WebPubSubTlsSettingsArgsBuilder internal constructor() {
    private var clientCertEnabled: Output<Boolean>? = null

    /**
     * @param value Request client certificate during TLS handshake if enabled
     */
    @JvmName("brjojgvtfbdhjyha")
    public suspend fun clientCertEnabled(`value`: Output<Boolean>) {
        this.clientCertEnabled = value
    }

    /**
     * @param value Request client certificate during TLS handshake if enabled
     */
    @JvmName("tkoissgmkakdmxow")
    public suspend fun clientCertEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientCertEnabled = mapped
    }

    internal fun build(): WebPubSubTlsSettingsArgs = WebPubSubTlsSettingsArgs(
        clientCertEnabled = clientCertEnabled,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/webpubsub/kotlin/inputs/WebPubSubTlsSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.webpubsub.kotlin.inputs

import com.pulumi.azurenative.webpubsub.inputs.WebPubSubTlsSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * TLS settings for the resource
 * @property clientCertEnabled Request client certificate during TLS handshake if enabled
 */
public data class WebPubSubTlsSettingsArgs(
    public val clientCertEnabled: Output<Boolean>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.webpubsub.inputs.WebPubSubTlsSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.webpubsub.inputs.WebPubSubTlsSettingsArgs =
        com.pulumi.azurenative.webpubsub.inputs.WebPubSubTlsSettingsArgs.builder()
            .clientCertEnabled(clientCertEnabled?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WebPubSubTlsSettingsArgs].
 */
@PulumiTagMarker
public class WebPubSubTlsSettingsArgsBuilder internal constructor() {
    private var clientCertEnabled: Output<Boolean>? = null

    /**
     * @param value Request client certificate during TLS handshake if enabled
     */
    @JvmName("icmyirjdfuxrmhnu")
    public suspend fun clientCertEnabled(`value`: Output<Boolean>) {
        this.clientCertEnabled = value
    }

    /**
     * @param value Request client certificate during TLS handshake if enabled
     */
    @JvmName("bvrytmuhrsnmdahf")
    public suspend fun clientCertEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.clientCertEnabled = mapped
    }

    internal fun build(): WebPubSubTlsSettingsArgs = WebPubSubTlsSettingsArgs(
        clientCertEnabled = clientCertEnabled,
    )
}
